@@ -4,21 +4,14 @@ import (
 	"context"
 	"text/template"
 
-	"github.com/hairyhenderson/gomplate/v3/data"
-	"github.com/hairyhenderson/gomplate/v3/funcs" //nolint:staticcheck
-	"github.com/hairyhenderson/gomplate/v3/internal/config"
+	"github.com/hairyhenderson/gomplate/v4/internal/config"
+	"github.com/hairyhenderson/gomplate/v4/internal/funcs"
 )
 
-// Funcs -
-// Deprecated: use CreateFuncs instead
-func Funcs(d *data.Data) template.FuncMap {
-	return CreateFuncs(context.Background(), d)
-}
-
 // CreateFuncs - function mappings are created here
-func CreateFuncs(ctx context.Context, d *data.Data) template.FuncMap {
+func CreateFuncs(ctx context.Context) template.FuncMap {
 	f := template.FuncMap{}
-	addToMap(f, funcs.CreateDataFuncs(ctx, d))
+	addToMap(f, funcs.CreateDataFuncs(ctx))
 	addToMap(f, funcs.CreateAWSFuncs(ctx))
 	addToMap(f, funcs.CreateGCPFuncs(ctx))
 	addToMap(f, funcs.CreateBase64Funcs(ctx))
@@ -38,6 +31,7 @@ func CreateFuncs(ctx context.Context, d *data.Data) template.FuncMap {
 	addToMap(f, funcs.CreateCollFuncs(ctx))
 	addToMap(f, funcs.CreateUUIDFuncs(ctx))
 	addToMap(f, funcs.CreateRandomFuncs(ctx))
+	addToMap(f, funcs.CreateSemverFuncs(ctx))
 	return f
 }
 
