@@ -2,13 +2,12 @@ package deprecated
 
 import (
 	"context"
-
-	"github.com/rs/zerolog"
+	"fmt"
+	"log/slog"
 )
 
 // WarnDeprecated - use this to warn about deprecated template functions or
 // datasources
 func WarnDeprecated(ctx context.Context, msg string) {
-	logger := zerolog.Ctx(ctx)
-	logger.Warn().Msgf("Deprecated: %s", msg)
+	slog.WarnContext(ctx, fmt.Sprintf("Deprecated: %s", msg))
 }
