@@ -8,6 +8,7 @@ package funcs
 import (
 	"context"
 	"fmt"
+	"math"
 	"reflect"
 	"strings"
 	"unicode/utf8"
@@ -151,6 +152,8 @@ func (StringFuncs) Abbrev(args ...interface{}) (string, error) {
 }
 
 // ReplaceAll -
+//
+//nolint:revive
 func (StringFuncs) ReplaceAll(old, new string, s interface{}) string {
 	return strings.ReplaceAll(conv.ToString(s), old, new)
 }
@@ -321,10 +324,10 @@ func (StringFuncs) ShellQuote(in interface{}) string {
 	switch val.Kind() {
 	case reflect.Array, reflect.Slice:
 		var sb strings.Builder
-		max := val.Len()
-		for n := 0; n < max; n++ {
+		vLen := val.Len()
+		for n := 0; n < vLen; n++ {
 			sb.WriteString(gompstrings.ShellQuote(conv.ToString(val.Index(n))))
-			if n+1 != max {
+			if n+1 != vLen {
 				sb.WriteRune(' ')
 			}
 		}
@@ -368,22 +371,32 @@ func (StringFuncs) WordWrap(args ...interface{}) (string, error) {
 		case string:
 			opts.LBSeq = a
 		default:
-			n, err := conv.ToInt(args[0])
+			n, err := conv.ToInt64(args[0])
 			if err != nil {
 				return "", fmt.Errorf("expected width to be a number: %w", err)
 			}
 
-			opts.Width = uint(n)
+			if n > math.MaxInt {
+				return "", fmt.Errorf("width too large: %d", n)
+			}
+
+			//nolint:gosec // G115 isn't applicable, we just checked
+			opts.Width = uint32(n)
 		}
 	}
 
 	if len(args) == 3 {
-		n, err := conv.ToInt(args[0])
+		n, err := conv.ToInt64(args[0])
 		if err != nil {
 			return "", fmt.Errorf("expected width to be a number: %w", err)
 		}
 
-		opts.Width = uint(n)
+		if n > math.MaxInt {
+			return "", fmt.Errorf("width too large: %d", n)
+		}
+
+		//nolint:gosec // G115 isn't applicable, we just checked
+		opts.Width = uint32(n)
 		opts.LBSeq = conv.ToString(args[1])
 	}
 
