@@ -5,20 +5,23 @@ import (
 	"os"
 	"testing"
 
-	"github.com/hairyhenderson/gomplate/v3/internal/iohelpers"
+	"github.com/hairyhenderson/gomplate/v4/internal/iohelpers"
+	"github.com/stretchr/testify/require"
 	"gotest.tools/v3/assert"
 	"gotest.tools/v3/assert/cmp"
-	testfs "gotest.tools/v3/fs"
+	tfs "gotest.tools/v3/fs"
 )
 
-func setupBasicTest(t *testing.T) *testfs.Dir {
-	tmpDir := testfs.NewDir(t, "gomplate-inttests",
-		testfs.WithFile("one", "hi\n", testfs.WithMode(0o640)),
-		testfs.WithFile("two", "hello\n"),
-		testfs.WithFile("broken", "", testfs.WithMode(0o000)),
-		testfs.WithDir("subdir",
-			testfs.WithFile("f1", "first\n", testfs.WithMode(0o640)),
-			testfs.WithFile("f2", "second\n"),
+func setupBasicTest(t *testing.T) *tfs.Dir {
+	t.Helper()
+
+	tmpDir := tfs.NewDir(t, "gomplate-inttests",
+		tfs.WithFile("one", "hi\n", tfs.WithMode(0o640)),
+		tfs.WithFile("two", "hello\n"),
+		tfs.WithFile("broken", "", tfs.WithMode(0o000)),
+		tfs.WithDir("subdir",
+			tfs.WithFile("f1", "first\n", tfs.WithMode(0o640)),
+			tfs.WithFile("f2", "second\n"),
 		),
 	)
 	t.Cleanup(tmpDir.Remove)
@@ -27,7 +30,7 @@ func setupBasicTest(t *testing.T) *testfs.Dir {
 
 func TestBasic_ReportsVersion(t *testing.T) {
 	o, e, err := cmd(t, "-v").run()
-	assert.NilError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "", e)
 	assert.Assert(t, cmp.Contains(o, "gomplate version "))
 }
@@ -86,11 +89,11 @@ func TestBasic_RoutesInputsToProperOutputs(t *testing.T) {
 	}
 	for _, v := range testdata {
 		info, err := os.Stat(v.path)
-		assert.NilError(t, err)
+		require.NoError(t, err)
 		m := iohelpers.NormalizeFileMode(v.mode)
 		assert.Equal(t, m, info.Mode(), v.path)
 		content, err := os.ReadFile(v.path)
-		assert.NilError(t, err)
+		require.NoError(t, err)
 		assert.Equal(t, v.content, string(content))
 	}
 }
@@ -175,12 +178,11 @@ func TestBasic_EmptyOutputSuppression(t *testing.T) {
 	tmpDir := setupBasicTest(t)
 	out := tmpDir.Join("out")
 	o, e, err := cmd(t, "-i", `{{print "\t  \n\n\r\n\t\t     \v\n"}}`,
-		"-o", out).
-		withEnv("GOMPLATE_SUPPRESS_EMPTY", "true").run()
+		"-o", out).run()
 	assertSuccess(t, o, e, err, "")
 
 	_, err = os.Stat(out)
-	assert.Equal(t, true, os.IsNotExist(err))
+	require.ErrorIs(t, err, fs.ErrNotExist)
 }
 
 func TestBasic_RoutesInputsToProperOutputsWithChmod(t *testing.T) {
@@ -207,10 +209,10 @@ func TestBasic_RoutesInputsToProperOutputsWithChmod(t *testing.T) {
 	}
 	for _, v := range testdata {
 		info, err := os.Stat(v.path)
-		assert.NilError(t, err)
+		require.NoError(t, err)
 		assert.Equal(t, iohelpers.NormalizeFileMode(v.mode), info.Mode())
 		content, err := os.ReadFile(v.path)
-		assert.NilError(t, err)
+		require.NoError(t, err)
 		assert.Equal(t, v.content, string(content))
 	}
 }
@@ -235,10 +237,10 @@ func TestBasic_OverridesOutputModeWithChmod(t *testing.T) {
 	}
 	for _, v := range testdata {
 		info, err := os.Stat(v.path)
-		assert.NilError(t, err)
+		require.NoError(t, err)
 		assert.Equal(t, iohelpers.NormalizeFileMode(v.mode), info.Mode())
 		content, err := os.ReadFile(v.path)
-		assert.NilError(t, err)
+		require.NoError(t, err)
 		assert.Equal(t, v.content, string(content))
 	}
 }
@@ -252,13 +254,13 @@ func TestBasic_AppliesChmodBeforeWrite(t *testing.T) {
 		"-f", tmpDir.Join("one"),
 		"-o", out,
 		"--chmod", "0644").run()
-	assert.NilError(t, err)
+	require.NoError(t, err)
 
 	info, err := os.Stat(out)
-	assert.NilError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, iohelpers.NormalizeFileMode(0o644), info.Mode())
 	content, err := os.ReadFile(out)
-	assert.NilError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "hi\n", string(content))
 }
 
@@ -269,10 +271,10 @@ func TestBasic_CreatesMissingDirectory(t *testing.T) {
 	assertSuccess(t, o, e, err, "")
 
 	info, err := os.Stat(out)
-	assert.NilError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, iohelpers.NormalizeFileMode(0o640), info.Mode())
 	content, err := os.ReadFile(out)
-	assert.NilError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "hi\n", string(content))
 
 	out = tmpDir.Join("outdir")
@@ -283,7 +285,7 @@ func TestBasic_CreatesMissingDirectory(t *testing.T) {
 	assertSuccess(t, o, e, err, "")
 
 	info, err = os.Stat(out)
-	assert.NilError(t, err)
+	require.NoError(t, err)
 
 	assert.Equal(t, iohelpers.NormalizeFileMode(0o755|fs.ModeDir), info.Mode())
 	assert.Equal(t, true, info.IsDir())
