@@ -10,23 +10,23 @@ import (
 	"text/template"
 	"time"
 
-	"github.com/hairyhenderson/gomplate/v3/internal/config"
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestBindPlugins(t *testing.T) {
 	ctx := context.Background()
 	fm := template.FuncMap{}
-	cfg := &config.Config{
-		Plugins: map[string]config.PluginConfig{},
+	cfg := &Config{
+		Plugins: map[string]PluginConfig{},
 	}
 	err := bindPlugins(ctx, cfg, fm)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.EqualValues(t, template.FuncMap{}, fm)
 
-	cfg.Plugins = map[string]config.PluginConfig{"foo": {Cmd: "bar"}}
+	cfg.Plugins = map[string]PluginConfig{"foo": {Cmd: "bar"}}
 	err = bindPlugins(ctx, cfg, fm)
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Contains(t, fm, "foo")
 
 	err = bindPlugins(ctx, cfg, fm)
@@ -69,9 +69,33 @@ func TestRun(t *testing.T) {
 		path:    "echo",
 	}
 	out, err := p.run("foo")
-	assert.NoError(t, err)
+	require.NoError(t, err)
 	assert.Equal(t, "", stderr.String())
 	assert.Equal(t, "foo", strings.TrimSpace(out.(string)))
+
+	p = &plugin{
+		ctx:     ctx,
+		timeout: 500 * time.Millisecond,
+		stderr:  stderr,
+		path:    "echo",
+		args:    []string{"foo", "bar"},
+	}
+	out, err = p.run()
+	require.NoError(t, err)
+	assert.Equal(t, "", stderr.String())
+	assert.Equal(t, "foo bar", strings.TrimSpace(out.(string)))
+
+	p = &plugin{
+		ctx:     ctx,
+		timeout: 500 * time.Millisecond,
+		stderr:  stderr,
+		path:    "echo",
+		args:    []string{"foo", "bar"},
+	}
+	out, err = p.run("baz", "qux")
+	require.NoError(t, err)
+	assert.Equal(t, "", stderr.String())
+	assert.Equal(t, "foo bar baz qux", strings.TrimSpace(out.(string)))
 }
 
 func ExamplePluginFunc() {
