@@ -5,21 +5,58 @@ import (
 	"testing"
 
 	"github.com/stretchr/testify/assert"
+	"github.com/stretchr/testify/require"
 )
 
 func TestIndent(t *testing.T) {
-	actual := "hello\nworld\n!"
+	in := "hello\nworld\n!"
 	expected := "  hello\n  world\n  !"
-	assert.Equal(t, actual, Indent(0, "  ", actual))
-	assert.Equal(t, actual, Indent(-1, "  ", actual))
-	assert.Equal(t, expected, Indent(1, "  ", actual))
-	assert.Equal(t, "\n", Indent(1, "  ", "\n"))
-	assert.Equal(t, "  foo\n", Indent(1, "  ", "foo\n"))
-	assert.Equal(t, "   foo", Indent(1, "   ", "foo"))
-	assert.Equal(t, "   foo", Indent(3, " ", "foo"))
 
-	// indenting with newline is not permitted
-	assert.Equal(t, "foo", Indent(3, "\n", "foo"))
+	actual, err := Indent(1, "  ", in)
+	require.NoError(t, err)
+	require.Equal(t, expected, actual)
+	actual, err = Indent(1, "  ", "\n")
+	require.NoError(t, err)
+	require.Equal(t, "\n", actual)
+	actual, err = Indent(1, "  ", "foo\n")
+	require.NoError(t, err)
+	require.Equal(t, "  foo\n", actual)
+	actual, err = Indent(1, "   ", "foo")
+	require.NoError(t, err)
+	require.Equal(t, "   foo", actual)
+	actual, err = Indent(3, " ", "foo")
+	require.NoError(t, err)
+	require.Equal(t, "   foo", actual)
+
+	// error cases
+	_, err = Indent(3, "\n", "foo")
+	require.Error(t, err)
+	_, err = Indent(-1, "  ", in)
+	require.Error(t, err)
+	_, err = Indent(0, "  ", in)
+	require.Error(t, err)
+}
+
+func BenchmarkIndent(b *testing.B) {
+	actual := "hello\nworld\n!"
+	longString := strings.Repeat("a fairly long string \n", 20)
+	outs := make([]string, b.N*8)
+	b.ResetTimer()
+	for i := 0; i < b.N; i++ {
+		outs[0+i*8], _ = Indent(20, " ", longString)
+		outs[1+i*8], _ = Indent(-1, "  ", actual)
+		outs[2+i*8], _ = Indent(1, "  ", actual)
+		outs[3+i*8], _ = Indent(1, "  ", "\n")
+		outs[4+i*8], _ = Indent(1, "  ", "foo\n")
+		outs[5+i*8], _ = Indent(1, "   ", "foo")
+		outs[6+i*8], _ = Indent(3, " ", "foo")
+		outs[7+i*8], _ = Indent(3, "\n", "foo")
+	}
+	b.StopTimer()
+
+	if len(outs) != b.N*8 {
+		b.Fail()
+	}
 }
 
 func TestTrunc(t *testing.T) {
@@ -126,3 +163,18 @@ that has been set.`
 	// 	in = strings.ReplaceAll(out, "\n", " ")
 	// 	assert.Equal(t, out, WordWrap(in, WordWrapOpts{Width: 100}))
 }
+
+func TestSkipLines(t *testing.T) {
+	out, _ := SkipLines(2, "\nfoo\nbar\n\nbaz")
+	assert.Equal(t, "bar\n\nbaz", out)
+
+	out, _ = SkipLines(0, "foo\nbar\n\nbaz")
+	assert.Equal(t, "foo\nbar\n\nbaz", out)
+
+	_, err := SkipLines(-1, "foo\nbar\n\nbaz")
+	require.Error(t, err)
+
+	out, err = SkipLines(4, "foo\nbar\n\nbaz")
+	require.NoError(t, err)
+	assert.Equal(t, "", out)
+}
